analphipy.PhiLFS
================

.. currentmodule:: analphipy

.. autoclass:: PhiLFS

   
   ..
      .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
      :toctree:
   
      ~PhiLFS.__init__
      ~PhiLFS.asdict
      ~PhiLFS.assign
      ~PhiLFS.assign_min_numeric
      ~PhiLFS.dphidr
      ~PhiLFS.minimize
      ~PhiLFS.new_like
      ~PhiLFS.phi
      ~PhiLFS.to_measures
      ~PhiLFS.to_nf
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
      :toctree:
   
      ~PhiLFS.phi_base
      ~PhiLFS.phi_min
      ~PhiLFS.r_min
      ~PhiLFS.rcut
      ~PhiLFS.segments
   
   

   
   
   .. rubric:: Dunder Methods

   .. autosummary::
      :toctree:
   
      ~PhiLFS.__repr__
   
   